@@ -11,11 +11,11 @@ def escape_html(s):
  '''
  return cgi.escape(s,quote=True).replace(':','&#58;')
 
-def unescape_html(s):
+def unescape_html(s,encoding="utf-8"):
  '''
    function to return unescaped html string
  '''
- return HTMLParser.HTMLParser().unescape(s).encode("utf-8")
+ return HTMLParser.HTMLParser().unescape(s).encode(encoding).replace('&#58;',':')
 
 class session:
  def __init__(self,host,port,username,password,database):
@@ -62,7 +62,6 @@ class session:
      self.cursor.execute(self.statement)#,self.escape_str(table))#,{"table":table})
  def drop_table(self,table):
      self.statement='''drop table if exists {}'''.format(pymysql.escape_string(table))
-     print (self.statement)
      self.cursor.execute(self.statement)
  def add_column_format(self,table,columns):
      return '''alter table {} add {}'''.format(pymysql.escape_string(table),self.dict_to_str(columns,escape=False))
